diff --git a/src/modules/network/network.c b/src/modules/network/network.c
index 700aac3..849a793 100644
--- a/src/modules/network/network.c
+++ b/src/modules/network/network.c
@@ -78,12 +78,17 @@ int wifi_set_mac_address()
 
 	struct ethernet_req_params eth_param;
 	memcpy(eth_param.mac_address.addr, mac_addr, 6);
-	// net_if_down(iface);
-	// if (net_if_down(iface))
-	// {
-	// 	printk("<Err> Couldn't shutdown WiFi interface\n");
-	// 	return -1;
-	// }
+	/* Set a local MAC address with Nordic OUI */
+	if (net_if_is_admin_up(iface)) {
+		printk("Interface is up, bringing down\n");
+		ret = net_if_down(iface);
+		if (ret < 0 && ret != -EALREADY) {
+			LOG_ERR("Cannot bring down iface (%d)", ret);
+			return ret;
+		}
+	} else {
+		printk("Interface is already down, proceeding\n");
+	}
 	printk("<Inf> Setting MAC address\n");
 	if (net_mgmt(NET_REQUEST_ETHERNET_SET_MAC_ADDRESS, iface, &eth_param, sizeof(struct ethernet_req_params)))
 	{
@@ -104,10 +109,12 @@ int wifi_set_mac_address()
 	// }
 	int err = net_if_up(iface);
 	printk("wake up interface err: %d\n", err);
-	if (err)
+	if (err < 0 && err != -EALREADY)
 	{
 		printk("<Err> Couldn't wake up interface\n");
 		return -3;
+	} else {
+		printk("Interface is up\n");
 	}
 
 	return 0;
@@ -115,9 +122,19 @@ int wifi_set_mac_address()
 
 static void network_task(void)
 {
-	wifi_set_mac_address();
 	int err;
 
+	/* Wait for the network interface to be ready. */
+	k_sleep(K_SECONDS(5));
+	err = wifi_set_mac_address();
+	if (err)
+	{
+		LOG_ERR("wifi_set_mac_address, error: %d", err);
+		SEND_FATAL_ERROR();
+		return;
+	}
+
+
 	gpio_pin_configure_dt(&PWR_UP, GPIO_OUTPUT);
 	gpio_pin_set_dt(&PWR_UP, 1);
 	/* Setup handler for Zephyr NET Connection Manager events. */
